@@ -26,7 +26,7 @@ Whenever stalker.db or something under it imported, the
 import logging
 
 from sqlalchemy import engine_from_config
-from sqlalchemy.exc import IntegrityError, InvalidRequestError
+from sqlalchemy.exc import IntegrityError
 
 from stalker import defaults
 from stalker.db.declarative import Base
@@ -94,12 +94,13 @@ def init():
 
     # register all Actions available for all SOM classes
     class_names = [
-        'Asset', 'TimeLog', 'Client', 'Daily', 'Department', 'Entity',
-        'FilenameTemplate', 'Group', 'ImageFormat', 'Link', 'Message', 'Note',
-        'Page', 'Permission', 'Project', 'Repository', 'Review', 'Scene',
+        'Asset', 'Client', 'Daily', 'Department', 'Entity', 'FilenameTemplate',
+        'Group', 'ImageFormat', 'Link', 'Message', 'Note', 'Page',
+        'Permission', 'Project', 'Repository', 'Review', 'Role', 'Scene',
         'Sequence', 'Shot', 'SimpleEntity', 'Status', 'StatusList',
-        'Structure', 'Studio', 'Tag', 'Task', 'Ticket', 'TicketLog', 'Type',
-        'User', 'Vacation', 'Version']
+        'Structure', 'Studio', 'Tag', 'Task', 'Ticket', 'TicketLog', 'TimeLog',
+        'Type', 'User', 'Vacation', 'Version'
+    ]
 
     for class_name in class_names:
         _temp = __import__(
@@ -170,7 +171,7 @@ def create_alembic_table():
     # don't forget to update the version_num (and the corresponding test
     # whenever a new alembic revision is created)
 
-    version_num = '5814290f49c7'
+    version_num = '856e70016b2'
 
     from sqlalchemy import Table, Column, Text
 
